@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Verilog::VCD::Writer;
-$Verilog::VCD::Writer::VERSION = '0.002';
+$Verilog::VCD::Writer::VERSION = '0.003';
 use DateTime;
 use Verilog::VCD::Writer::Module;
 
@@ -126,30 +126,30 @@ Verilog::VCD::Writer - VCD waveform File creation module.
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
-	use Verilog::VCD::Writer;
+    use Verilog::VCD::Writer;
 
-	my $writer=Verilog::VCD::Writer->new(timescale=>'1 ns',vcdfile=>"test.vcd");
-	$writer->addComment("Author:Vijayvithal");
+    my $writer = Verilog::VCD::Writer->new(timescale=>'1 ns',vcdfile=>"test.vcd");
+    $writer->addComment("Author:Vijayvithal");
 
-	my $top=$writer->addModule("top"); # Create toplevel module
-	my $TX=$writer->addSignal("TX",7,0); #Add Signals to top
-	my $RX=$writer->addSignal("RX",7,0);
+    my $top = $writer->addModule("top"); # Create toplevel module
+    my $TX  = $top->addSignal("TX",7,0); #Add Signals to top
+    my $RX  = $top->addSignal("RX",7,0);
 
-	my $dut=$top->addModule("DUT");  Create SubModule
-	$dut->dupSignal($TX,"TX",7,0); #Duplicate signals from Top in submodule
-	$dut->dupSignal($RX,"RX",7,0);
-	
-	$writer->writeHeaders(); # Output the VCD Header.
-	$writer->setTime(0); # Time 0
-	$writer->addValue($TX,0); # Record Transition
-	$writer->addValue($RX,0);
-	$writer->setTime(5); # Time 1ns
-	$writer->addValue($TX,1);
-	$writer->addValue($RX,0);
+    my $dut = $writer->addModule("DUT");  #Create SubModule
+    $dut->dupSignal($TX,"TX",7,0); #Duplicate signals from Top in submodule
+    $dut->dupSignal($RX,"RX",7,0);
+
+    $writer->writeHeaders(); # Output the VCD Header.
+    $writer->setTime(0); # Time 0
+    $writer->addValue($TX,0); # Record Transition
+    $writer->addValue($RX,0);
+    $writer->setTime(5); # Time 1ns
+    $writer->addValue($TX,1);
+    $writer->addValue($RX,0);
 
 =head1 METHODS
 
